module.exports = defineTest({
	description: 'do not make assumptions about its value when using undefined as a parameter name'
});
